CustomerCreate class
Constructors
Properties
- billing → Ing
-
final
- email → String
-
final
- firstName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
final
- password → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shipping → Ing
-
final
- username → String
-
final
Methods
-
copyWith(
{String? email, String? firstName, String? lastName, String? username, String? password, Ing? billing, Ing? shipping}) → CustomerCreate -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited